@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Functions in the puppet language can be written in Ruby and distributed in
 # puppet modules. The function is written by creating a file in the module's
 # `lib/puppet/functions/<modulename>` directory, where `<modulename>` is
@@ -271,6 +273,7 @@ module Puppet::Functions
     unless the_class.method_defined?(func_name)
       raise ArgumentError, _("Function Creation Error, cannot create a default dispatcher for function '%{func_name}', no method with this name found") % { func_name: func_name }
     end
+
     any_signature(*min_max_param(the_class.instance_method(func_name)))
   end
 
@@ -302,7 +305,6 @@ module Puppet::Functions
   #
   # @api public
   class Function < Puppet::Pops::Functions::Function
-
     # @api private
     def self.builder
       DispatcherBuilder.new(dispatcher, Puppet::Pops::Types::PCallableType::DEFAULT, loader)
@@ -349,6 +351,7 @@ module Puppet::Functions
       if loader.nil?
         raise ArgumentError, _("No loader present. Call create_loaded_function(:myname, loader,...), instead of 'create_function' if running tests")
       end
+
       aliases = LocalTypeAliasesBuilder.new(loader, name)
       aliases.instance_eval(&block)
       # Add the loaded types to the builder
@@ -385,7 +388,6 @@ module Puppet::Functions
     end
   end
 
-
   # Public api methods of the DispatcherBuilder are available within dispatch()
   # blocks declared in a Puppet::Function.create_function() call.
   #
@@ -412,6 +414,7 @@ module Puppet::Functions
     def param(type, name)
       internal_param(type, name)
       raise ArgumentError, _('A required parameter cannot be added after an optional parameter') if @min != @max
+
       @min += 1
       @max += 1
     end
@@ -461,6 +464,7 @@ module Puppet::Functions
     def required_repeated_param(type, name)
       internal_param(type, name, true)
       raise ArgumentError, _('A required repeated parameter cannot be added after an optional parameter') if @min != @max
+
       @min += 1
       @max = :default
     end
@@ -521,6 +525,7 @@ module Puppet::Functions
       unless type.is_a?(String) || type.is_a?(Puppet::Pops::Types::PAnyType)
         raise ArgumentError, _("Argument to 'return_type' must be a String reference to a Puppet Data Type. Got %{type_class}") % { type_class: type.class }
       end
+
       @return_type = type
     end
 
@@ -590,15 +595,14 @@ module Puppet::Functions
         Puppet::Pops::Types::TypeParser.singleton.parse(type_string, loader)
       rescue StandardError => e
         raise ArgumentError, _("Parsing of type string '\"%{type_string}\"' failed with message: <%{message}>.\n") % {
-            type_string: type_string,
-            message: e.message
+          type_string: type_string,
+          message: e.message
         }
       end
     end
     private :internal_type_parse
   end
 
-
   # The LocalTypeAliasBuilder is used by the 'local_types' method to collect the individual
   # type aliases given by the function's author.
   #
@@ -636,7 +640,7 @@ module Puppet::Functions
             assignment_string: assignment_string,
             message: e.message,
             ruby_file_location: rb_location
-        }
+          }
       end
       unless result.body.kind_of?(Puppet::Pops::Model::TypeAlias)
         rb_location = rb_location.gsub(/:in.*$/, '')
@@ -680,15 +684,14 @@ module Puppet::Functions
   end
 
   class Function3x < InternalFunction
-
     # Table of optimized parameter names - 0 to 5 parameters
     PARAM_NAMES = [
       [],
-      ['p0'.freeze].freeze,
-      ['p0'.freeze, 'p1'.freeze].freeze,
-      ['p0'.freeze, 'p1'.freeze, 'p2'.freeze].freeze,
-      ['p0'.freeze, 'p1'.freeze, 'p2'.freeze, 'p3'.freeze].freeze,
-      ['p0'.freeze, 'p1'.freeze, 'p2'.freeze, 'p3'.freeze, 'p4'.freeze].freeze,
+      ['p0'].freeze,
+      ['p0', 'p1'].freeze,
+      ['p0', 'p1', 'p2'].freeze,
+      ['p0', 'p1', 'p2', 'p3'].freeze,
+      ['p0', 'p1', 'p2', 'p3', 'p4'].freeze,
     ]
 
     # Creates an anonymous Function3x class that wraps a 3x function
@@ -738,7 +741,6 @@ module Puppet::Functions
       # When function is not an rvalue function, make sure it produces nil
       #
       the_class.class_eval do
-
         # Bypasses making the  call via the dispatcher to make sure errors
         # are reported exactly the same way as in 3x. The dispatcher is still needed as it is
         # used to support other features than calling.
@@ -800,7 +802,6 @@ module Puppet::Functions
     end
   end
 
-
   # Injection and Weaving of parameters
   # ---
   # It is possible to inject and weave a set of well known parameters into a call.
