@@ -1,5 +1,7 @@
-require 'puppet/external/dot'
-require 'puppet/relationship'
+# frozen_string_literal: true
+
+require_relative '../../puppet/external/dot'
+require_relative '../../puppet/relationship'
 require 'set'
 
 # A hopefully-faster graph class to replace the use of GRATR.
@@ -38,11 +40,12 @@ class Puppet::Graph::SimpleGraph
     @downstream_from.clear
   end
 
-  # Which resources depend upon the given resource.
+  # Which resources the given resource depends on.
   def dependencies(resource)
     vertex?(resource) ? upstream_from_vertex(resource).keys : []
   end
 
+  # Which resources depend upon the given resource.
   def dependents(resource)
     vertex?(resource) ? downstream_from_vertex(resource).keys : []
   end
@@ -141,7 +144,7 @@ class Puppet::Graph::SimpleGraph
             end
             s[:scc] << this_scc
           end
-          recur.pop               # done with this node, finally.
+          recur.pop # done with this node, finally.
         end
 
       when :after_recursion then
@@ -196,7 +199,7 @@ class Puppet::Graph::SimpleGraph
   # through the graph first, which are more likely to be interesting to the
   # user.  I think; it would be interesting to verify that. --daniel 2011-01-23
   def paths_in_cycle(cycle, max_paths = 1)
-    #TRANSLATORS "negative or zero" refers to the count of paths
+    # TRANSLATORS "negative or zero" refers to the count of paths
     raise ArgumentError, _("negative or zero max_paths") if max_paths < 1
 
     # Calculate our filtered outbound vertex lists...
@@ -209,7 +212,7 @@ class Puppet::Graph::SimpleGraph
 
     # frame struct is vertex, [path]
     stack = [[cycle.first, []]]
-    while frame = stack.shift do #rubocop:disable Lint/AssignmentInCondition
+    while frame = stack.shift do # rubocop:disable Lint/AssignmentInCondition
       if frame[1].member?(frame[0]) then
         found << frame[1] + [frame[0]]
         break if found.length >= max_paths
@@ -240,7 +243,7 @@ class Puppet::Graph::SimpleGraph
       filename = write_cycles_to_graph(cycles)
       message += _("Cycle graph written to %{filename}.") % { filename: filename }
     else
-      #TRANSLATORS '--graph' refers to a command line option and OmniGraffle and GraphViz are program names and should not be translated
+      # TRANSLATORS '--graph' refers to a command line option and OmniGraffle and GraphViz are program names and should not be translated
       message += _("Try the '--graph' option and opening the resulting '.dot' file in OmniGraffle or GraphViz")
     end
     Puppet.err(message)
@@ -277,6 +280,7 @@ class Puppet::Graph::SimpleGraph
   # Remove a vertex from the graph.
   def remove_vertex!(v)
     return unless vertex?(v)
+
     @upstream_from.clear
     @downstream_from.clear
     (@in_to[v].values+@out_from[v].values).flatten.each { |e| remove_edge!(e) }
@@ -298,6 +302,7 @@ class Puppet::Graph::SimpleGraph
   # since they have to specify what kind of edge it is.
   def add_edge(e,*a)
     return add_relationship(e,*a) unless a.empty?
+
     e = Puppet::Relationship.from_data_hash(e) if e.is_a?(Hash)
     @upstream_from.clear
     @downstream_from.clear
@@ -329,7 +334,7 @@ class Puppet::Graph::SimpleGraph
   end
 
   def each_edge
-    @in_to.each { |t,ns| ns.each { |s,es| es.each { |e| yield e }}}
+    @in_to.each { |_t,ns| ns.each { |_s,es| es.each { |e| yield e }}}
   end
 
   # Remove an edge from our graph.
@@ -346,6 +351,7 @@ class Puppet::Graph::SimpleGraph
   def adjacent(v, options = {})
     ns = (options[:direction] == :in) ? @in_to[v] : @out_from[v]
     return [] unless ns
+
     (options[:type] == :edges) ? ns.values.flatten : ns.keys
   end
 
@@ -359,6 +365,7 @@ class Puppet::Graph::SimpleGraph
     until stack.empty?
       node = stack.shift
       next if seen.member? node
+
       connected = adjacent(node, :direction => direction)
       connected.each do |target|
         yield node, target
@@ -380,6 +387,7 @@ class Puppet::Graph::SimpleGraph
 
   def downstream_from_vertex(v)
     return @downstream_from[v] if @downstream_from[v]
+
     result = @downstream_from[v] = {}
     @out_from[v].keys.each do |node|
       result[node] = 1
@@ -394,6 +402,7 @@ class Puppet::Graph::SimpleGraph
 
   def upstream_from_vertex(v)
     return @upstream_from[v] if @upstream_from[v]
+
     result = @upstream_from[v] = {}
     @in_to[v].keys.each do |node|
       result[node] = 1
@@ -445,17 +454,17 @@ class Puppet::Graph::SimpleGraph
     edge_klass = directed? ? DOT::DOTDirectedEdge : DOT::DOTEdge
     vertices.each do |v|
       name = v.ref
-      params = {'name'     => stringify(name),
-        'fontsize' => fontsize,
-        'label'    => name}
+      params = {'name' => stringify(name),
+                'fontsize' => fontsize,
+                'label' => name}
       v_label = v.ref
       params.merge!(v_label) if v_label and v_label.kind_of? Hash
       graph << DOT::DOTNode.new(params)
     end
     edges.each do |e|
-      params = {'from'     => stringify(e.source.ref),
-        'to'       => stringify(e.target.ref),
-        'fontsize' => fontsize }
+      params = {'from' => stringify(e.source.ref),
+                'to' => stringify(e.target.ref),
+                'fontsize' => fontsize }
       e_label = e.ref
       params.merge!(e_label) if e_label and e_label.kind_of? Hash
       graph << edge_klass.new(params)
@@ -505,26 +514,26 @@ class Puppet::Graph::SimpleGraph
   def to_data_hash
     hash = { 'edges' => edges.map(&:to_data_hash) }
     hash['vertices'] = if self.class.use_new_yaml_format
-      vertices
-    else
-      # Represented in YAML using the old (version 2.6) format.
-      result = {}
-      vertices.each do |vertex|
-        adjacencies = {}
-        [:in, :out].each do |direction|
-          direction_hash = {}
-          adjacencies[direction.to_s] = direction_hash
-          adjacent(vertex, :direction => direction, :type => :edges).each do |edge|
-            other_vertex = direction == :in ? edge.source : edge.target
-            (direction_hash[other_vertex.to_s] ||= []) << edge
-          end
-          direction_hash.each_pair { |key, edges| direction_hash[key] = edges.uniq.map(&:to_data_hash) }
-        end
-        vname = vertex.to_s
-        result[vname] = { 'adjacencies' => adjacencies, 'vertex' => vname }
-      end
-      result
-    end
+                         vertices
+                       else
+                         # Represented in YAML using the old (version 2.6) format.
+                         result = {}
+                         vertices.each do |vertex|
+                           adjacencies = {}
+                           [:in, :out].each do |direction|
+                             direction_hash = {}
+                             adjacencies[direction.to_s] = direction_hash
+                             adjacent(vertex, :direction => direction, :type => :edges).each do |edge|
+                               other_vertex = direction == :in ? edge.source : edge.target
+                               (direction_hash[other_vertex.to_s] ||= []) << edge
+                             end
+                             direction_hash.each_pair { |key, edges| direction_hash[key] = edges.uniq.map(&:to_data_hash) }
+                           end
+                           vname = vertex.to_s
+                           result[vname] = { 'adjacencies' => adjacencies, 'vertex' => vname }
+                         end
+                         result
+                       end
     hash
   end
 
