@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 # The Compiler service is used to submit and retrieve data from the
 # puppetserver.
 #
 # @api public
 class Puppet::HTTP::Service::Compiler < Puppet::HTTP::Service
   # @return [String] Default API for the Compiler service
-  API = '/puppet/v3'.freeze
+  API = '/puppet/v3'
 
   # Use `Puppet::HTTP::Session.route_to(:puppet)` to create or get an instance of this class.
   #
@@ -164,6 +166,7 @@ class Puppet::HTTP::Service::Compiler < Puppet::HTTP::Service
       raise ArgumentError.new("The 'persistence' hash is missing the keys: #{missing.join(', ')}")
     end
     raise ArgumentError.new("Facts must be a Hash not a #{facts.class}") unless facts.nil? || facts.is_a?(Hash)
+
     body = {
       certname: certname,
       persistence: persistence,
@@ -305,9 +308,9 @@ class Puppet::HTTP::Service::Compiler < Puppet::HTTP::Service
   # @api public
   def put_filebucket_file(path, body:, environment:)
     headers = add_puppet_headers({
-      'Accept' => 'application/octet-stream',
-      'Content-Type' => 'application/octet-stream'
-      })
+                                   'Accept' => 'application/octet-stream',
+                                   'Content-Type' => 'application/octet-stream'
+                                 })
 
     response = @client.put(
       with_base_url("/file_bucket_file/#{path}"),
