@@ -1,5 +1,7 @@
-require 'puppet/transaction/report'
-require 'puppet/indirector/yaml'
+# frozen_string_literal: true
+
+require_relative '../../../puppet/transaction/report'
+require_relative '../../../puppet/indirector/yaml'
 
 class Puppet::Transaction::Report::Yaml < Puppet::Indirector::Yaml
   include Puppet::Util::SymbolicFileMode
