@@ -1,4 +1,6 @@
 # encoding: UTF-8
+# frozen_string_literal: true
+
 # Load standard libraries
 require 'pathname'
 require 'fileutils'
@@ -69,7 +71,7 @@ module Puppet
     # Builds a formatted tree from a list of node hashes containing +:text+
     # and +:dependencies+ keys.
     def self.format_tree(nodes, level = 0)
-      str = ''
+      str = ''.dup
       nodes.each_with_index do |node, i|
         last_node = nodes.length - 1 == i
         deps = node[:dependencies] || []
@@ -131,7 +133,6 @@ module Puppet
 
       # Note: environment will have expanded the path
       options[:target_dir] = face_environment.full_modulepath.first
-
     end
 
     # Given a hash of options, we should discover or create a
