@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 # Factory is a helper class that makes construction of a Pops Model
 # much more convenient. It can be viewed as a small internal DSL for model
 # constructions.
@@ -12,19 +13,19 @@ module Model
 class Factory
   # Shared build_visitor, since there are many instances of Factory being used
 
-  KEY_LENGTH = 'length'.freeze
-  KEY_OFFSET = 'offset'.freeze
-  KEY_LOCATOR = 'locator'.freeze
-  KEY_OPERATOR = 'operator'.freeze
+  KEY_LENGTH = 'length'
+  KEY_OFFSET = 'offset'
+  KEY_LOCATOR = 'locator'
+  KEY_OPERATOR = 'operator'
 
-  KEY_VALUE = 'value'.freeze
-  KEY_KEYS = 'keys'.freeze
-  KEY_NAME = 'name'.freeze
-  KEY_BODY = 'body'.freeze
-  KEY_EXPR = 'expr'.freeze
-  KEY_LEFT_EXPR = 'left_expr'.freeze
-  KEY_RIGHT_EXPR = 'right_expr'.freeze
-  KEY_PARAMETERS = 'parameters'.freeze
+  KEY_VALUE = 'value'
+  KEY_KEYS = 'keys'
+  KEY_NAME = 'name'
+  KEY_BODY = 'body'
+  KEY_EXPR = 'expr'
+  KEY_LEFT_EXPR = 'left_expr'
+  KEY_RIGHT_EXPR = 'right_expr'
+  KEY_PARAMETERS = 'parameters'
 
   BUILD_VISITOR = Visitor.new(self, 'build')
   INFER_VISITOR = Visitor.new(self, 'infer')
@@ -121,13 +122,6 @@ class Factory
 
   # Building of Model classes
 
-  def build_Application(o, n, ps, body)
-    @init_hash[KEY_NAME] = n
-    @init_hash[KEY_PARAMETERS] = ps
-    b = f_build_body(body)
-    @init_hash[KEY_BODY] = b unless b.nil?
-  end
-
   def build_ArithmeticExpression(o, op, a, b)
     @init_hash[KEY_OPERATOR] = op
     build_BinaryExpression(o, a, b)
@@ -388,13 +382,6 @@ class Factory
     @init_hash['return_type'] = return_type unless return_type.nil?
   end
 
-  def build_CapabilityMapping(o, kind, component, capability, mappings)
-    @init_hash['kind'] = kind
-    @init_hash['component'] = component
-    @init_hash['capability'] = capability
-    @init_hash['mappings'] = mappings
-  end
-
   def build_NodeDefinition(o, hosts, parent, body)
     @init_hash['host_matches'] = hosts
     @init_hash['parent'] = parent unless parent.nil? # no nop here
@@ -402,11 +389,6 @@ class Factory
     @init_hash[KEY_BODY] = b unless b.nil?
   end
 
-  def build_SiteDefinition(o, body)
-    b = f_build_body(body)
-    @init_hash[KEY_BODY] = b unless b.nil?
-  end
-
   def build_Parameter(o, name, expr)
     @init_hash[KEY_NAME] = name
     @init_hash[KEY_VALUE] = expr
@@ -445,22 +427,6 @@ class Factory
     @init_hash['selectors'] = selectors
   end
 
-  # Builds a SubLocatedExpression - this wraps the expression in a sublocation configured
-  # from the given token
-  # A SubLocated holds its own locator that is used for subexpressions holding positions relative
-  # to what it describes.
-  #
-  def build_SubLocatedExpression(o, token, expression)
-    @init_hash[KEY_EXPR] = expression
-    @init_hash[KEY_OFFSET] = token.offset
-    @init_hash[KEY_LENGTH] =  token.length
-    locator = token.locator
-    @init_hash[KEY_LOCATOR] = locator
-    @init_hash['leading_line_count'] = locator.leading_line_count
-    @init_hash['leading_line_offset'] = locator.leading_line_offset
-    @init_hash['line_offsets'] = locator.line_index # index of lines in sublocated
-  end
-
   def build_SelectorEntry(o, matching, value)
     @init_hash['matching_expr'] = matching
     @init_hash['value_expr'] = value
@@ -633,7 +599,6 @@ class Factory
 
   def lambda=(lambda)
     @init_hash['lambda'] = lambda
-    self
   end
 
   # Assignment =
@@ -681,6 +646,7 @@ class Factory
   def self.set_resource_form(expr, form)
     # Note: Validation handles illegal combinations
     return false unless expr.instance_of?(self) && expr.model_class <= AbstractResource
+
     expr['form'] = form
     return true
   end
@@ -729,7 +695,7 @@ class Factory
 
   def self.block(*args);                 new(BlockExpression, args.map { |arg| infer(arg) }); end
 
-  def self.string(*args);                new(ConcatenatedString, args.map { |arg| infer(arg) });           end
+  def self.string(*args);                new(ConcatenatedString, args.map { |arg| infer(arg) }); end
 
   def self.text(o);                      infer(o).text;                                  end
 
@@ -759,8 +725,6 @@ class Factory
 
   def self.NODE(hosts, parent, body);    new(NodeDefinition, hosts, parent, body);       end
 
-  def self.SITE(body);                   new(SiteDefinition, body);                      end
-
   # Parameters
 
   # Mark parameter as capturing the rest of arguments
@@ -846,7 +810,7 @@ class Factory
       end
     else
       # Bad number should already have been caught by lexer - this should never happen
-      #TRANSLATORS 'NUMBER' refers to a method name and the 'name_or_numeric' was the passed in value and should not be translated
+      # TRANSLATORS 'NUMBER' refers to a method name and the 'name_or_numeric' was the passed in value and should not be translated
       raise ArgumentError, _("Internal Error, NUMBER token does not contain a valid number, %{name_or_numeric}") %
           { name_or_numeric: name_or_numeric }
     end
@@ -967,14 +931,6 @@ class Factory
     new(ResourceTypeDefinition, name, parameters, body)
   end
 
-  def self.CAPABILITY_MAPPING(kind, component, cap_name, mappings)
-    new(CapabilityMapping, kind, component, cap_name, mappings)
-  end
-
-  def self.APPLICATION(name, parameters, body)
-    new(Application, name, parameters, body)
-  end
-
   def self.PLAN(name, parameters, body)
     new(PlanDefinition, name, parameters, body, nil)
   end
@@ -1016,19 +972,19 @@ class Factory
     'realize' => true,
     'include' => true,
     'contain' => true,
-    'tag'     => true,
+    'tag' => true,
 
-    'debug'   => true,
-    'info'    => true,
-    'notice'  => true,
+    'debug' => true,
+    'info' => true,
+    'notice' => true,
     'warning' => true,
-    'err'     => true,
+    'err' => true,
 
-    'fail'    => true,
-    'import'  => true,  # discontinued, but transform it to make it call error reporting function
-    'break'   => true,
-    'next'    => true,
-    'return'  => true
+    'fail' => true,
+    'import' => true, # discontinued, but transform it to make it call error reporting function
+    'break' => true,
+    'next' => true,
+    'return' => true
   }.freeze
 
   # Returns true if the given name is a "statement keyword" (require, include, contain,
@@ -1040,6 +996,7 @@ class Factory
 
   class ArgsToNonCallError < RuntimeError
     attr_reader :args, :name_expr
+
     def initialize(args, name_expr)
       @args = args
       @name_expr = name_expr
@@ -1088,8 +1045,10 @@ class Factory
     # Returning nil means accepting the given as a potential resource expression
     return nil unless attribute_ops.is_a? Array
     return nil unless left.model_class <= QualifiedName
+
     keyed_entries = attribute_ops.map do |ao|
       return nil if ao[KEY_OPERATOR] == '+>'
+
       KEY_ENTRY(infer(ao['attribute_name']), ao['value_expr'])
     end
     a_hash = HASH(keyed_entries)
