@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Puppet::Pops
 module Types
   # @api private
@@ -126,6 +128,7 @@ module Types
 
     def chop_path(element_index)
       return self if element_index >= @path.size
+
       chopped_path = @path.clone
       chopped_path.delete_at(element_index)
       copy = self.clone
@@ -481,10 +484,6 @@ module Types
 
   # @api private
   class CountMismatch < SizeMismatch
-    def initialize(path, expected, actual)
-      super(path, expected, actual)
-    end
-
     def message(variant, position)
       min = expected.from || 0
       max = expected.to || Float::INFINITY
@@ -512,7 +511,7 @@ module Types
     end
 
     def tense_deprecated
-      #TRANSLATORS TypeMismatchDescriber is a class name and 'tense' is a method name and should not be translated
+      # TRANSLATORS TypeMismatchDescriber is a class name and 'tense' is a method name and should not be translated
       message = _("Passing a 'tense' argument to the TypeMismatchDescriber is deprecated and ignored.")
       message += ' ' + _("Everything is now reported using present tense")
       Puppet.warn_once('deprecations', 'typemismatch#tense', message)
@@ -532,6 +531,7 @@ module Types
       errors = describe_struct_signature(params_struct, given_hash, missing_ok).flatten
       case errors.size
       when 0
+        # do nothing
       when 1
         raise Puppet::ParseError.new("#{subject}:#{errors[0].format}")
       else
@@ -572,6 +572,7 @@ module Types
         errors = describe(param_type, TypeCalculator.singleton.infer_set(value).generalize, [ParameterPathElement.new(param_name)])
         case errors.size
         when 0
+          # do nothing
         when 1
           raise Puppet::ParseError.new("#{subject}:#{errors[0].format}")
         else
@@ -582,10 +583,11 @@ module Types
     end
 
     def get_deferred_function_return_type(value)
-      func = Puppet.lookup(:loaders).private_environment_loader.
-               load(:function, value.name)
+      func = Puppet.lookup(:loaders).private_environment_loader
+               .load(:function, value.name)
       dispatcher = func.class.dispatcher.find_matching_dispatcher(value.arguments)
       raise ArgumentError, "No matching arity found for #{func.class.name} with arguments #{value.arguments}" unless dispatcher
+
       dispatcher.type.return_type
     end
     private :get_deferred_function_return_type
@@ -600,7 +602,7 @@ module Types
     # @return [Array<Mismatch>] An array of found errors. An empty array indicates no errors.
     def describe_struct_signature(params_struct, param_hash, missing_ok = false)
       param_type_hash = params_struct.hashed_elements
-      result =  param_hash.each_key.reject { |name| param_type_hash.include?(name) }.map { |name| InvalidParameter.new(nil, name) }
+      result = param_hash.each_key.reject { |name| param_type_hash.include?(name) }.map { |name| InvalidParameter.new(nil, name) }
 
       params_struct.elements.each do |elem|
         name = elem.name
@@ -740,6 +742,7 @@ module Types
       types.each_with_index do |vt, index|
         d = describe(vt, actual, path + [VariantPathElement.new(index)])
         return EMPTY_ARRAY if d.empty?
+
         variant_descriptions << d
       end
       descriptions = merge_descriptions(path.length, SizeMismatch, variant_descriptions)
@@ -760,6 +763,7 @@ module Types
           # If they all have the same canonical path, then we can compact this into one
           generic_mismatch = mismatches.inject do |prev, curr|
             break nil unless prev.canonical_path == curr.canonical_path
+
             prev.merge(prev.path, curr)
           end
           unless generic_mismatch.nil?
@@ -775,6 +779,7 @@ module Types
 
     def describe_POptionalType(expected, original, actual, path)
       return EMPTY_ARRAY if actual.is_a?(PUndefType) || expected.optional_type.nil?
+
       internal_describe(expected.optional_type, original.is_a?(PTypeAliasType) ? original : expected, actual, path)
     end
 
@@ -888,6 +893,7 @@ module Types
 
     def describe_tuple(expected, original, actual, path, size_mismatch_class)
       return EMPTY_ARRAY if expected == actual || expected.types.empty? && (actual.is_a?(PArrayType))
+
       expected_size = expected.size_type || TypeFactory.range(*expected.size_range)
 
       if actual.is_a?(PTupleType)
