@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # A Provider is an implementation of the actions that manage resources (of some type) on a system.
 # This class is the base class for all implementation of a Puppet Provider.
 #
@@ -40,8 +42,8 @@ class Puppet::Provider
   include Puppet::Util::Warnings
   extend Puppet::Util::Warnings
 
-  require 'puppet/confiner'
-  require 'puppet/provider/command'
+  require_relative '../puppet/confiner'
+  require_relative 'provider/command'
 
   extend Puppet::Confiner
 
@@ -117,19 +119,6 @@ class Puppet::Provider
     Puppet::Util::Execution.execpipe(*args, &block)
   end
 
-  # Convenience methods - see class method with the same name.
-  # @return (see self.execfail)
-  # @deprecated
-  def execfail(*args)
-    Puppet::Util::Execution.execfail(*args)
-  end
-
-  # (see Puppet::Util::Execution.execfail)
-  # @deprecated
-  def self.execfail(*args)
-    Puppet::Util::Execution.execfail(*args)
-  end
-
   # Returns the absolute path to the executable for the command referenced by the given name.
   # @raise [Puppet::DevError] if the name does not reference an existing command.
   # @return [String] the absolute path to the found executable for the command
@@ -210,7 +199,7 @@ class Puppet::Provider
   # @note the name ´has_command´ looks odd in an API context, but makes more sense when seen in the internal
   #   DSL context where a Provider is declaratively defined.
   # @api public
-  #
+  # rubocop:disable Naming/PredicateName
   def self.has_command(name, path, &block)
     name = name.intern
     command = CommandDefiner.define(name, path, self, &block)
@@ -222,6 +211,7 @@ class Puppet::Provider
       return command.execute(*args)
     end
   end
+  # rubocop:enable Naming/PredicateName
 
   # Internal helper class when creating commands - undocumented.
   # @api private
@@ -242,7 +232,7 @@ class Puppet::Provider
       @custom_environment = {}
     end
 
-    def is_optional
+    def is_optional # rubocop:disable Naming/PredicateName
       @optional = true
     end
 
@@ -278,18 +268,14 @@ class Puppet::Provider
   # @api private
   def self.default_match
     return nil if some_default_match(@notdefaults) # Blacklist means this provider cannot be a default
+
     some_default_match(@defaults)
   end
 
   def self.some_default_match(defaultlist)
     defaultlist.find do |default|
       default.all? do |key, values|
-        case key
-          when :feature
-            feature_match(values)
-          else
-            fact_match(key, values)
-        end
+        key == :feature ? feature_match(values) : fact_match(key, values)
       end
     end
   end
@@ -414,6 +400,7 @@ class Puppet::Provider
     [resource_type.validproperties, resource_type.parameters].flatten.each do |attr|
       attr = attr.intern
       next if attr == :name
+
       define_method(attr) do
         if @property_hash[attr].nil?
           :absent
@@ -488,7 +475,7 @@ class Puppet::Provider
 
   dochook(:commands) do
     if @commands.length > 0
-      return "Required binaries: " + @commands.collect do |n, c|
+      return "Required binaries: " + @commands.collect do |_n, c|
         "`#{c}`"
       end.sort.join(", ") + "."
     end
@@ -590,6 +577,7 @@ class Puppet::Provider
   def <=>(other)
     # We can only have ordering against other providers.
     return nil unless other.is_a? Puppet::Provider
+
     # Otherwise, order by the providers class name.
     return self.class.name <=> other.class.name
   end
