@@ -1,11 +1,13 @@
+# frozen_string_literal: true
+
 require_relative '../../../puppet/util/windows'
 
 Puppet::Type.type(:group).provide :windows_adsi do
   desc "Local group management for Windows. Group members can be both users and groups.
     Additionally, local groups can contain domain users."
 
-  defaultfor :operatingsystem => :windows
-  confine    :operatingsystem => :windows
+  defaultfor 'os.name' => :windows
+  confine    'os.name' => :windows
 
   has_features :manages_members
 
@@ -39,6 +41,7 @@ Puppet::Type.type(:group).provide :windows_adsi do
 
   def members_to_s(users)
     return '' if users.nil? or !users.kind_of?(Array)
+
     users = users.map do |user_name|
       sid = Puppet::Util::Windows::SID.name_to_principal(user_name)
       if !sid
