@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../../../puppet/util/package/version/gem'
 require_relative '../../../puppet/util/package/version/range'
 require_relative '../../../puppet/provider/package_targetable'
@@ -46,7 +48,7 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
   # Define the default provider package command as optional when the provider is targetable.
   # Doing do defers the evaluation of provider suitability until all commands are evaluated.
 
-  has_command(:gemcmd, 'gem34') do
+  has_command(:gemcmd, 'gem32') do
     is_optional
   end
 
@@ -55,9 +57,11 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
   # that contains the content of PATH but without puppet/bin dir.
   # This is used to pass a custom PATH and execute commands in a controlled environment
   def self.windows_path_without_puppet_bin
-    @path ||= Puppet::Util.get_env('PATH').split(File::PATH_SEPARATOR)
-                                          .reject { |dir| dir =~ /puppet\\bin$/ }
-                                          .join(File::PATH_SEPARATOR)
+    # rubocop:disable Naming/MemoizedInstanceVariableName
+    @path ||= ENV['PATH'].split(File::PATH_SEPARATOR)
+                         .reject { |dir| dir =~ /puppet\\bin$/ }
+                         .join(File::PATH_SEPARATOR)
+    # rubocop:enable Naming/MemoizedInstanceVariableName
   end
 
   private_class_method :windows_path_without_puppet_bin
@@ -73,7 +77,7 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
     validate_command(command)
     cmd = [command] << command_options
 
-    custom_environment = {'HOME'=>Puppet::Util.get_env('HOME')}.merge(custom_environment)
+    custom_environment = {'HOME'=>ENV['HOME']}.merge(custom_environment)
 
     if Puppet::Util::Platform.windows?
       custom_environment[:PATH] = windows_path_without_puppet_bin
@@ -115,9 +119,9 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
     end
 
     begin
-      list = execute_gem_command(options[:command], command_options).lines.
-        map {|set| gemsplit(set) }.
-        reject {|x| x.nil? }
+      list = execute_gem_command(options[:command], command_options).lines
+        .map {|set| gemsplit(set) }
+        .reject {|x| x.nil? }
     rescue Puppet::ExecutionFailure => detail
       raise Puppet::Error, _("Could not list gems: %{detail}") % { detail: detail }, detail.backtrace
     end
@@ -140,8 +144,8 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
       gem_name = $1
       versions = $2.sub('default: ', '').split(/,\s*/)
       {
-        :name     => gem_name,
-        :ensure   => versions.map{|v| v.split[0]},
+        :name => gem_name,
+        :ensure => versions.map{|v| v.split[0]},
         :provider => name
       }
     else
@@ -152,6 +156,7 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
 
   def insync?(is)
     return false unless is && is != :absent
+
     is = [is] unless is.is_a? Array
     should = @resource[:ensure]
 
