@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'timeout'
 
 # Solaris 10 SMF-style services.
@@ -18,9 +20,9 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
     be imported if it does not exist.
   EOT
 
-  defaultfor :osfamily => :solaris
+  defaultfor 'os.family' => :solaris
 
-  confine :osfamily => :solaris
+  confine 'os.family' => :solaris
 
   commands :adm => "/usr/sbin/svcadm",
            :svcs => "/usr/bin/svcs",
@@ -101,14 +103,14 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
 
   # Returns true if the provider supports incomplete services.
   def supports_incomplete_services?
-    Puppet::Util::Package.versioncmp(Puppet.runtime[:facter].value(:operatingsystemrelease), '11.1') >= 0
+    Puppet::Util::Package.versioncmp(Puppet.runtime[:facter].value('os.release.full'), '11.1') >= 0
   end
 
   # Returns true if the service is complete. A complete service is a service that
   # has the general/complete property defined.
   def complete_service?
     unless supports_incomplete_services?
-      raise Puppet::Error, _("Cannot query if the %{service} service is complete: The concept of complete/incomplete services was introduced in Solaris 11.1. You are on a Solaris %{release} machine.") % { service: @resource[:name], release: Puppet.runtime[:facter].value(:operatingsystemrelease) }
+      raise Puppet::Error, _("Cannot query if the %{service} service is complete: The concept of complete/incomplete services was introduced in Solaris 11.1. You are on a Solaris %{release} machine.") % { service: @resource[:name], release: Puppet.runtime[:facter].value('os.release.full') }
     end
 
     return @complete_service if @complete_service
@@ -129,6 +131,7 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
 
   def enabled?
     return :false unless service_exists?
+
     _property, _type, value = svccfg("-s", self.service_fmri, "listprop", "general/enabled").split(' ')
     value == 'true' ? :true : :false
   end
@@ -138,7 +141,7 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
   end
 
   def restartcmd
-    if Puppet::Util::Package.versioncmp(Puppet.runtime[:facter].value(:operatingsystemrelease), '11.2') >= 0
+    if Puppet::Util::Package.versioncmp(Puppet.runtime[:facter].value('os.release.full'), '11.2') >= 0
       [command(:adm), :restart, "-s", self.service_fmri]
     else
       # Synchronous restart only supported in Solaris 11.2 and above
@@ -167,6 +170,7 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
       loop do
         states = self.service_states
         break if desired_states.include?(states[:current]) && states[:next].nil?
+
         Kernel.sleep(1)
       end
     end
@@ -221,10 +225,10 @@ Puppet::Type.type(:service).provide :smf, :parent => :base do
       return :degraded
     when "legacy_run"
       raise Puppet::Error,
-        "Cannot manage legacy services through SMF"
+            "Cannot manage legacy services through SMF"
     else
       raise Puppet::Error,
-        "Unmanageable state '#{state}' on service #{self.name}"
+            "Unmanageable state '#{state}' on service #{self.name}"
     end
   end
 
