@@ -1,13 +1,15 @@
-require 'puppet'
-require 'puppet/util/plist' if Puppet.features.cfpropertylist?
+# frozen_string_literal: true
+
+require_relative '../../../puppet'
+require_relative '../../../puppet/util/plist' if Puppet.features.cfpropertylist?
 require 'base64'
 
 Puppet::Type.type(:user).provide :directoryservice do
   desc "User management on OS X."
 
-##                   ##
-## Provider Settings ##
-##                   ##
+  ##                   ##
+  ## Provider Settings ##
+  ##                   ##
 
   # Provider command declarations
   commands :uuidgen      => '/usr/bin/uuidgen'
@@ -16,9 +18,9 @@ Puppet::Type.type(:user).provide :directoryservice do
   commands :dscacheutil  => '/usr/bin/dscacheutil'
 
   # Provider confines and defaults
-  confine    :operatingsystem => :darwin
-  confine    :feature         => :cfpropertylist
-  defaultfor :operatingsystem => :darwin
+  confine    'os.name' => :darwin
+  confine    :feature => :cfpropertylist
+  defaultfor 'os.name' => :darwin
 
   # Need this to create getter/setter methods automagically
   # This command creates methods that return @property_hash[:value]
@@ -30,29 +32,29 @@ Puppet::Type.type(:user).provide :directoryservice do
   # 10.8 Passwords use a PBKDF2 salt value
   has_features :manages_password_salt
 
-  #provider can set the user's shell
+  # provider can set the user's shell
   has_feature :manages_shell
 
-##               ##
-## Class Methods ##
-##               ##
+  ##               ##
+  ## Class Methods ##
+  ##               ##
 
   # This method exists to map the dscl values to the correct Puppet
   # properties. This stays relatively consistent, but who knows what
   # Apple will do next year...
   def self.ds_to_ns_attribute_map
     {
-      'RecordName'       => :name,
-      'PrimaryGroupID'   => :gid,
+      'RecordName' => :name,
+      'PrimaryGroupID' => :gid,
       'NFSHomeDirectory' => :home,
-      'UserShell'        => :shell,
-      'UniqueID'         => :uid,
-      'RealName'         => :comment,
-      'Password'         => :password,
-      'GeneratedUID'     => :guid,
-      'IPAddress'        => :ip_address,
-      'ENetAddress'      => :en_address,
-      'GroupMembership'  => :members,
+      'UserShell' => :shell,
+      'UniqueID' => :uid,
+      'RealName' => :comment,
+      'Password' => :password,
+      'GeneratedUID' => :guid,
+      'IPAddress' => :ip_address,
+      'ENetAddress' => :en_address,
+      'GroupMembership' => :members,
     }
   end
 
@@ -104,19 +106,20 @@ Puppet::Type.type(:user).provide :directoryservice do
     input_hash.each_key do |key|
       ds_attribute = key.sub("dsAttrTypeStandard:", "")
       next unless ds_to_ns_attribute_map.keys.include?(ds_attribute)
+
       ds_value = input_hash[key]
       case ds_to_ns_attribute_map[ds_attribute]
-        when :gid, :uid
-          # OS X stores objects like uid/gid as strings.
-          # Try casting to an integer for these cases to be
-          # consistent with the other providers and the group type
-          # validation
-          begin
-            ds_value = Integer(ds_value[0])
-          rescue ArgumentError
-            ds_value = ds_value[0]
-          end
-        else ds_value = ds_value[0]
+      when :gid, :uid
+        # OS X stores objects like uid/gid as strings.
+        # Try casting to an integer for these cases to be
+        # consistent with the other providers and the group type
+        # validation
+        begin
+          ds_value = Integer(ds_value[0])
+        rescue ArgumentError
+          ds_value = ds_value[0]
+        end
+      else ds_value = ds_value[0]
       end
       attribute_hash[ds_to_ns_attribute_map[ds_attribute]] = ds_value
     end
@@ -147,9 +150,9 @@ Puppet::Type.type(:user).provide :directoryservice do
     else
       embedded_binary_plist = get_embedded_binary_plist(attribute_hash[:shadowhashdata])
       if embedded_binary_plist['SALTED-SHA512-PBKDF2']
-        attribute_hash[:password]   = get_salted_sha512_pbkdf2('entropy', embedded_binary_plist)
-        attribute_hash[:salt]       = get_salted_sha512_pbkdf2('salt', embedded_binary_plist)
-        attribute_hash[:iterations] = get_salted_sha512_pbkdf2('iterations', embedded_binary_plist)
+        attribute_hash[:password]   = get_salted_sha512_pbkdf2('entropy', embedded_binary_plist, attribute_hash[:name])
+        attribute_hash[:salt]       = get_salted_sha512_pbkdf2('salt', embedded_binary_plist, attribute_hash[:name])
+        attribute_hash[:iterations] = get_salted_sha512_pbkdf2('iterations', embedded_binary_plist, attribute_hash[:name])
       elsif embedded_binary_plist['SALTED-SHA512']
         attribute_hash[:password] = get_salted_sha512(embedded_binary_plist)
       end
@@ -159,13 +162,17 @@ Puppet::Type.type(:user).provide :directoryservice do
   end
 
   def self.get_os_version
-    @os_version ||= Puppet.runtime[:facter].value(:macosx_productversion_major)
+    # rubocop:disable Naming/MemoizedInstanceVariableName
+    @os_version ||= Puppet.runtime[:facter].value('os.macosx.version.major')
+    # rubocop:enable Naming/MemoizedInstanceVariableName
   end
 
   # Use dscl to retrieve an array of hashes containing attributes about all
   # of the local groups on the machine.
   def self.get_list_of_groups
+    # rubocop:disable Naming/MemoizedInstanceVariableName
     @groups ||= Puppet::Util::Plist.parse_plist(dscl '-plist', '.', 'readall', '/Groups')
+    # rubocop:enable Naming/MemoizedInstanceVariableName
   end
 
   # Perform a dscl lookup at the path specified for the specific keyname
@@ -205,16 +212,19 @@ Puppet::Type.type(:user).provide :directoryservice do
   # according to which field is passed.  Arguments passed are the hash
   # containing the value read from the 'ShadowHashData' key in the User's
   # plist, and the field to be read (one of 'entropy', 'salt', or 'iterations')
-  def self.get_salted_sha512_pbkdf2(field, embedded_binary_plist)
+  def self.get_salted_sha512_pbkdf2(field, embedded_binary_plist, user_name = "")
     case field
     when 'salt', 'entropy'
-      embedded_binary_plist['SALTED-SHA512-PBKDF2'][field].unpack('H*').first
+      value = embedded_binary_plist['SALTED-SHA512-PBKDF2'][field]
+      if value == nil
+        raise Puppet::Error, "Invalid #{field} given for user #{user_name}"
+      end
+
+      value.unpack('H*').first
     when 'iterations'
       Integer(embedded_binary_plist['SALTED-SHA512-PBKDF2'][field])
     else
-      raise Puppet::Error, 'Puppet has tried to read an incorrect value from the ' +
-           "SALTED-SHA512-PBKDF2 hash. Acceptable fields are 'salt', " +
-           "'entropy', or 'iterations'."
+      raise Puppet::Error, "Puppet has tried to read an incorrect value from the user #{user_name} in the SALTED-SHA512-PBKDF2 hash. Acceptable fields are 'salt', 'entropy', or 'iterations'."
     end
   end
 
@@ -225,6 +235,7 @@ Puppet::Type.type(:user).provide :directoryservice do
     password_hash_file = "#{password_hash_dir}/#{guid}"
     if Puppet::FileSystem.exist?(password_hash_file) and File.file?(password_hash_file)
       raise Puppet::Error, "Could not read password hash file at #{password_hash_file}" if not File.readable?(password_hash_file)
+
       f = File.new(password_hash_file)
       password_hash = f.read
       f.close
@@ -232,10 +243,9 @@ Puppet::Type.type(:user).provide :directoryservice do
     password_hash
   end
 
-
-##                   ##
-## Ensurable Methods ##
-##                   ##
+  ##                   ##
+  ## Ensurable Methods ##
+  ##                   ##
 
   def exists?
     begin
@@ -262,6 +272,7 @@ Puppet::Type.type(:user).provide :directoryservice do
     # Iterate through valid User type properties
     valid_properties.each do |attribute|
       next if attribute == :ensure
+
       value = @resource.should(attribute)
 
       # Value defaults
@@ -315,9 +326,9 @@ Puppet::Type.type(:user).provide :directoryservice do
     dscl '.', '-delete', "/Users/#{@resource.name}"
   end
 
-##                       ##
-## Getter/Setter Methods ##
-##                       ##
+  ##                       ##
+  ## Getter/Setter Methods ##
+  ##                       ##
 
   # In the setter method we're only going to take action on groups for which
   # the user is not currently a member.
@@ -347,7 +358,7 @@ Puppet::Type.type(:user).provide :directoryservice do
       end
     else
       if value.length != 256
-         raise Puppet::Error, "OS X versions > 10.7 require a Salted SHA512 PBKDF2 password hash of 256 characters. Please check your password and try again."
+        raise Puppet::Error, "OS X versions > 10.7 require a Salted SHA512 PBKDF2 password hash of 256 characters. Please check your password and try again."
       end
 
       assert_full_pbkdf2_password
@@ -443,6 +454,7 @@ Puppet::Type.type(:user).provide :directoryservice do
         if %w(home uid).include?(setter_method)
           raise Puppet::Error, "OS X version #{self.class.get_os_version} does not allow changing #{setter_method} using puppet"
         end
+
         begin
           dscl '.', '-change', "/Users/#{resource.name}", self.class.ns_to_ds_attribute_map[setter_method.intern], @property_hash[setter_method.intern], value
         rescue Puppet::ExecutionFailure => e
@@ -460,7 +472,6 @@ Puppet::Type.type(:user).provide :directoryservice do
     end
   end
 
-
   ##                ##
   ## Helper Methods ##
   ##                ##
@@ -469,7 +480,7 @@ Puppet::Type.type(:user).provide :directoryservice do
     missing = [:password, :salt, :iterations].select { |parameter| @resource[parameter].nil? }
 
     if !missing.empty?
-       raise Puppet::Error, "OS X versions > 10\.7 use PBKDF2 password hashes, which requires all three of salt, iterations, and password hash. This resource is missing: #{missing.join(', ')}."
+      raise Puppet::Error, "OS X versions > 10\.7 use PBKDF2 password hashes, which requires all three of salt, iterations, and password hash. This resource is missing: #{missing.join(', ')}."
     end
   end
 
@@ -501,7 +512,7 @@ Puppet::Type.type(:user).provide :directoryservice do
 
   # Create the new user with dscl
   def create_new_user(username)
-    dscl '.', '-create',  "/Users/#{username}"
+    dscl '.', '-create', "/Users/#{username}"
   end
 
   # Get the next available uid on the system by getting a list of user ids,
@@ -568,7 +579,7 @@ Puppet::Type.type(:user).provide :directoryservice do
   # ShadowHashData key of a user's plist, or false if it doesn't exist.
   def get_shadow_hash_data(users_plist)
     if users_plist['ShadowHashData']
-      password_hash_plist  = users_plist['ShadowHashData'][0]
+      password_hash_plist = users_plist['ShadowHashData'][0]
       self.class.convert_binary_to_hash(password_hash_plist)
     else
       false
@@ -609,9 +620,9 @@ Puppet::Type.type(:user).provide :directoryservice do
   # for information regarding the dsimport syntax
   def write_and_import_shadow_hash_data(data_plist)
     Tempfile.create("dsimport_#{@resource.name}", :encoding => Encoding::ASCII) do |dsimport_file|
-      dsimport_file.write <<-DSIMPORT
-0x0A 0x5C 0x3A 0x2C dsRecTypeStandard:Users 2 dsAttrTypeStandard:RecordName base64:dsAttrTypeNative:ShadowHashData
-#{@resource.name}:#{Base64.strict_encode64(data_plist)}
+      dsimport_file.write <<~DSIMPORT
+        0x0A 0x5C 0x3A 0x2C dsRecTypeStandard:Users 2 dsAttrTypeStandard:RecordName base64:dsAttrTypeNative:ShadowHashData
+        #{@resource.name}:#{Base64.strict_encode64(data_plist)}
       DSIMPORT
       dsimport_file.flush
       # Delete the user's existing ShadowHashData, since dsimport appends, not replaces
@@ -634,7 +645,7 @@ Puppet::Type.type(:user).provide :directoryservice do
   def set_salted_sha512(users_plist, shadow_hash_data, value)
     unless shadow_hash_data
       shadow_hash_data = Hash.new
-      shadow_hash_data['SALTED-SHA512'] = ''
+      shadow_hash_data['SALTED-SHA512'] = ''.dup
     end
     shadow_hash_data['SALTED-SHA512'] = base64_decode_string(value)
     binary_plist = self.class.convert_hash_to_binary(shadow_hash_data)
@@ -672,16 +683,6 @@ Puppet::Type.type(:user).provide :directoryservice do
     set_shadow_hash_data(users_plist, binary_plist)
   end
 
-  # This is a simple wrapper method for writing values to a file.
-  def write_to_file(filename, value)
-    Puppet.deprecation_warning("Puppet::Type.type(:user).provider(:directoryservice).write_to_file is deprecated and will be removed in Puppet 5.")
-    begin
-      File.open(filename, 'w') { |f| f.write(value)}
-    rescue Errno::EACCES => detail
-      raise Puppet::Error, "Could not write to file #{filename}: #{detail}", detail.backtrace
-    end
-  end
-
   private
 
   SHA512_PBKDF2_AUTHENTICATION_AUTHORITY = ';ShadowHash;HASHLIST:<SALTED-SHA512-PBKDF2,SRP-RFC5054-4096-SHA512-PBKDF2>'
