@@ -1,23 +1,26 @@
-require 'puppet/settings/base_setting'
+# frozen_string_literal: true
+
+require_relative '../../puppet/settings/base_setting'
 
 # A setting that represents a scheduling priority, and evaluates to an
 # OS-specific priority level.
 class Puppet::Settings::PrioritySetting < Puppet::Settings::BaseSetting
   PRIORITY_MAP =
     if Puppet::Util::Platform.windows?
-      require 'puppet/util/windows/process'
+      require_relative '../../puppet/util/windows/process'
+      require_relative '../../puppet/ffi/windows/constants'
       {
-        :high    => Puppet::Util::Windows::Process::HIGH_PRIORITY_CLASS,
-        :normal  => Puppet::Util::Windows::Process::NORMAL_PRIORITY_CLASS,
-        :low     => Puppet::Util::Windows::Process::BELOW_NORMAL_PRIORITY_CLASS,
-        :idle    => Puppet::Util::Windows::Process::IDLE_PRIORITY_CLASS
+        :high => Puppet::FFI::Windows::Constants::HIGH_PRIORITY_CLASS,
+        :normal => Puppet::FFI::Windows::Constants::NORMAL_PRIORITY_CLASS,
+        :low => Puppet::FFI::Windows::Constants::BELOW_NORMAL_PRIORITY_CLASS,
+        :idle => Puppet::FFI::Windows::Constants::IDLE_PRIORITY_CLASS
       }
     else
       {
-        :high    => -10,
-        :normal  => 0,
-        :low     => 10,
-        :idle    => 19
+        :high => -10,
+        :normal => 0,
+        :low => 10,
+        :idle => 19
       }
     end
 
