@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../../puppet'
 require_relative '../../puppet/parameter/boolean'
 
@@ -77,22 +79,22 @@ Puppet::Type.newtype(:resources) do
       value = [value] unless value.is_a? Array
       value.flatten.collect do |v|
         case v
-          when Integer
-            v
-          when String
-            Integer(v)
-          else
-            raise ArgumentError, _("Invalid value %{value}.") % { value: v.inspect }
+        when Integer
+          v
+        when String
+          Integer(v)
+        else
+          raise ArgumentError, _("Invalid value %{value}.") % { value: v.inspect }
         end
       end
     end
   end
 
   WINDOWS_SYSTEM_SID_REGEXES =
-      # Administrator, Guest, Domain Admins, Schema Admins, Enterprise Admins.
-      # https://support.microsoft.com/en-us/help/243330/well-known-security-identifiers-in-windows-operating-systems
-      [/S-1-5-21.+-500/, /S-1-5-21.+-501/, /S-1-5-21.+-512/, /S-1-5-21.+-518/,
-       /S-1-5-21.+-519/]
+    # Administrator, Guest, Domain Admins, Schema Admins, Enterprise Admins.
+    # https://support.microsoft.com/en-us/help/243330/well-known-security-identifiers-in-windows-operating-systems
+    [/S-1-5-21.+-500/, /S-1-5-21.+-501/, /S-1-5-21.+-512/, /S-1-5-21.+-518/,
+     /S-1-5-21.+-519/]
 
   def check(resource)
     @checkmethod ||= "#{self[:name]}_check"
@@ -105,22 +107,23 @@ Puppet::Type.newtype(:resources) do
   end
 
   def able_to_ensure_absent?(resource)
-      resource[:ensure] = :absent
+    resource[:ensure] = :absent
   rescue ArgumentError, Puppet::Error
-      err _("The 'ensure' attribute on %{name} resources does not accept 'absent' as a value") % { name: self[:name] }
-      false
+    err _("The 'ensure' attribute on %{name} resources does not accept 'absent' as a value") % { name: self[:name] }
+    false
   end
 
   # Generate any new resources we need to manage.  This is pretty hackish
   # right now, because it only supports purging.
   def generate
     return [] unless self.purge?
-    resource_type.instances.
-      reject { |r| catalog.resource_refs.include? r.ref }.
-      select { |r| check(r) }.
-      select { |r| r.class.validproperty?(:ensure) }.
-      select { |r| able_to_ensure_absent?(r) }.
-      each { |resource|
+
+    resource_type.instances
+      .reject { |r| catalog.resource_refs.include? r.ref }
+      .select { |r| check(r) }
+      .select { |r| r.class.validproperty?(:ensure) }
+      .select { |r| able_to_ensure_absent?(r) }
+      .each { |resource|
         resource.copy_metaparams(@parameters)
         resource.purging
       }
@@ -132,6 +135,7 @@ Puppet::Type.newtype(:resources) do
       unless type
         raise Puppet::DevError, _("Could not find resource type")
       end
+
       @resource_type = type
     end
     @resource_type
@@ -141,6 +145,7 @@ Puppet::Type.newtype(:resources) do
   def user_check(resource)
     return true unless self[:name] == "user"
     return true unless self[:unless_system_user]
+
     resource[:audit] = :uid
     current_values = resource.retrieve_resource
     current_uid = current_values[resource.property(:uid)]
@@ -148,6 +153,7 @@ Puppet::Type.newtype(:resources) do
 
     return false if system_users.include?(resource[:name])
     return false if unless_uids && unless_uids.include?(current_uid)
+
     if current_uid.is_a?(String)
       # Windows user; is a system user if any regex matches.
       WINDOWS_SYSTEM_SID_REGEXES.none? { |regex| current_uid =~ regex }
@@ -171,12 +177,11 @@ Puppet::Type.newtype(:resources) do
     end
 
     # Otherwise, use a sensible default based on the OS family
-    @system_users_max_uid ||= case Puppet.runtime[:facter].value(:osfamily)
-      when 'OpenBSD', 'FreeBSD'
-        999
-      else
-        499
-    end
+    @system_users_max_uid ||=
+      case Puppet.runtime[:facter].value('os.family')
+      when 'OpenBSD', 'FreeBSD' then 999
+      else                           499
+      end
 
     @system_users_max_uid
   end
