@@ -1,28 +1,32 @@
+# frozen_string_literal: true
+
 # A module to collect utility functions.
 
 require 'English'
-require 'puppet/error'
-require 'puppet/util/execution_stub'
+require_relative '../puppet/error'
+require_relative 'util/execution_stub'
 require 'uri'
 require 'pathname'
 require 'ostruct'
-require 'puppet/util/platform'
-require 'puppet/util/windows'
-require 'puppet/util/symbolic_file_mode'
-require 'puppet/file_system/uniquefile'
+require_relative 'util/platform'
+require_relative 'util/windows'
+require_relative 'util/symbolic_file_mode'
+require_relative '../puppet/file_system/uniquefile'
 require 'securerandom'
-require 'puppet/util/character_encoding'
+require_relative 'util/character_encoding'
 
 module Puppet
 module Util
-  require 'puppet/util/monkey_patches'
+  require_relative 'util/monkey_patches'
   require 'benchmark'
 
   # These are all for backward compatibility -- these are methods that used
   # to be in Puppet::Util but have been moved into external modules.
-  require 'puppet/util/posix'
+  require_relative 'util/posix'
   extend Puppet::Util::POSIX
 
+  require_relative 'util/windows/process' if Puppet::Util::Platform.windows?
+
   extend Puppet::Util::SymbolicFileMode
 
   def default_env
@@ -32,103 +36,58 @@ module Util
   end
   module_function :default_env
 
-  # @param name [String] The name of the environment variable to retrieve
-  # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
-  # @return [String] Value of the specified environment variable.  nil if it does not exist
+  def create_erb(content)
+    ERB.new(content, trim_mode: '-')
+  end
+  module_function :create_erb
+
+  # @deprecated Use ENV instead
   # @api private
   def get_env(name, mode = default_env)
-    if mode == :windows
-      Puppet::Util::Windows::Process.get_environment_strings.each do |key, value |
-        if name.casecmp(key) == 0 then
-          return value
-        end
-      end
-      return nil
-    else
-      ENV[name]
-    end
+    ENV[name]
   end
   module_function :get_env
 
-  # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
-  # @return [Hash] A hashtable of all environment variables
+  # @deprecated Use ENV instead
   # @api private
   def get_environment(mode = default_env)
-    case mode
-      when :posix
-        ENV.to_hash
-      when :windows
-        Puppet::Util::Windows::Process.get_environment_strings
-      else
-        raise _("Unable to retrieve the environment for mode %{mode}") % { mode: mode }
-    end
+    ENV.to_hash
   end
   module_function :get_environment
 
-  # Removes all environment variables
-  # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
+  # @deprecated Use ENV instead
   # @api private
   def clear_environment(mode = default_env)
-    case mode
-      when :posix
-        ENV.clear
-      when :windows
-        Puppet::Util::Windows::Process.get_environment_strings.each do |key, _|
-          Puppet::Util::Windows::Process.set_environment_variable(key, nil)
-        end
-      else
-        raise _("Unable to clear the environment for mode %{mode}") % { mode: mode }
-    end
+    ENV.clear
   end
   module_function :clear_environment
 
-  # @param name [String] The name of the environment variable to set
-  # @param value [String] The value to set the variable to.  nil deletes the environment variable
-  # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
+  # @deprecated Use ENV instead
   # @api private
   def set_env(name, value = nil, mode = default_env)
-    case mode
-      when :posix
-        ENV[name] = value
-      when :windows
-        Puppet::Util::Windows::Process.set_environment_variable(name,value)
-      else
-        raise _("Unable to set the environment variable %{name} for mode %{mode}") % { name: name, mode: mode }
-    end
+    ENV[name] = value
   end
   module_function :set_env
 
-  # @param name [Hash] Environment variables to merge into the existing environment.  nil values will remove the variable
-  # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
+  # @deprecated Use ENV instead
   # @api private
   def merge_environment(env_hash, mode = default_env)
-    case mode
-      when :posix
-        env_hash.each { |name, val| ENV[name.to_s] = val }
-      when :windows
-        env_hash.each do |name, val|
-          Puppet::Util::Windows::Process.set_environment_variable(name.to_s, val)
-        end
-      else
-        raise _("Unable to merge given values into the current environment for mode %{mode}") % { mode: mode }
-    end
+    ENV.merge!(hash.transform_keys(&:to_s))
   end
   module_function :merge_environment
 
   # Run some code with a specific environment.  Resets the environment back to
   # what it was at the end of the code.
-  # Windows can store Unicode chars in the environment as keys or values, but
-  # Ruby's ENV tries to roundtrip them through the local codepage, which can
-  # cause encoding problems - underlying helpers use Windows APIs on Windows
-  # see https://bugs.ruby-lang.org/issues/8822
+  #
+  # @param hash [Hash{String,Symbol => String}] Environment variables to override the current environment.
+  # @param mode [Symbol] ignored
   def withenv(hash, mode = :posix)
-    saved = get_environment(mode)
-    merge_environment(hash, mode)
-    yield
-  ensure
-    if saved
-      clear_environment(mode)
-      merge_environment(saved, mode)
+    saved = ENV.to_hash
+    begin
+      ENV.merge!(hash.transform_keys(&:to_s))
+      yield
+    ensure
+      ENV.replace(saved)
     end
   end
   module_function :withenv
@@ -144,7 +103,6 @@ module Util
     end
   end
 
-
   # Change the process to a different user
   def self.chuser
     group = Puppet[:group]
@@ -157,7 +115,7 @@ module Util
 
         # Don't exit on failed group changes, since it's
         # not fatal
-        #exit(74)
+        # exit(74)
       end
     end
 
@@ -219,7 +177,7 @@ module Util
                args.pop
              end
 
-    #TRANSLATORS 'benchmark' is a method name and should not be translated
+    # TRANSLATORS 'benchmark' is a method name and should not be translated
     raise Puppet::DevError, _("Failed to provide level to benchmark") unless level
 
     unless level == :none or object.respond_to? level
@@ -250,23 +208,23 @@ module Util
     if absolute_path?(bin)
       return bin if FileTest.file? bin and FileTest.executable? bin
     else
-      exts = Puppet::Util.get_env('PATHEXT')
+      exts = ENV['PATHEXT']
       exts = exts ? exts.split(File::PATH_SEPARATOR) : %w[.COM .EXE .BAT .CMD]
-      Puppet::Util.get_env('PATH').split(File::PATH_SEPARATOR).each do |dir|
+      ENV['PATH'].split(File::PATH_SEPARATOR).each do |dir|
         begin
           dest = File.expand_path(File.join(dir, bin))
         rescue ArgumentError => e
           # if the user's PATH contains a literal tilde (~) character and HOME is not set, we may get
           # an ArgumentError here.  Let's check to see if that is the case; if not, re-raise whatever error
           # was thrown.
-          if e.to_s =~ /HOME/ and (Puppet::Util.get_env('HOME').nil? || Puppet::Util.get_env('HOME') == "")
+          if e.to_s =~ /HOME/ and (ENV['HOME'].nil? || ENV['HOME'] == "")
             # if we get here they have a tilde in their PATH.  We'll issue a single warning about this and then
             # ignore this path element and carry on with our lives.
-            #TRANSLATORS PATH and HOME are environment variables and should not be translated
+            # TRANSLATORS PATH and HOME are environment variables and should not be translated
             Puppet::Util::Warnings.warnonce(_("PATH contains a ~ character, and HOME is not set; ignoring PATH element '%{dir}'.") % { dir: dir })
           elsif e.to_s =~ /doesn't exist|can't find user/
             # ...otherwise, we just skip the non-existent entry, and do nothing.
-            #TRANSLATORS PATH is an environment variable and should not be translated
+            # TRANSLATORS PATH is an environment variable and should not be translated
             Puppet::Util::Warnings.warnonce(_("Couldn't expand PATH containing a ~ character; ignoring PATH element '%{dir}'.") % { dir: dir })
           else
             raise
@@ -374,7 +332,7 @@ module Util
   end
   module_function :uri_to_path
 
-  RFC_3986_URI_REGEX = /^(?<scheme>([^:\/?#]+):)?(?<authority>\/\/([^\/?#]*))?(?<path>[^?#]*)(\?(?<query>[^#]*))?(#(?<fragment>.*))?$/
+  RFC_3986_URI_REGEX = /^(?<scheme>(?:[^:\/?#]+):)?(?<authority>\/\/(?:[^\/?#]*))?(?<path>[^?#]*)(?:\?(?<query>[^#]*))?(?:#(?<fragment>.*))?$/
 
   # Percent-encodes a URI query parameter per RFC3986 - https://tools.ietf.org/html/rfc3986
   #
@@ -451,8 +409,7 @@ module Util
   def uri_encode(path, opts = { :allow_fragment => false })
     raise ArgumentError.new(_('path may not be nil')) if path.nil?
 
-    # ensure string starts as UTF-8 for the sake of Ruby 1.9.3
-    encoded = ''.encode!(Encoding::UTF_8)
+    encoded = ''.dup
 
     # parse uri into named matches, then reassemble properly encoded
     parts = path.match(RFC_3986_URI_REGEX)
@@ -465,17 +422,7 @@ module Util
     # URI::parse and URI::Generic.build don't like paths encoded with CGI.escape
     # URI.escape does not change / to %2F and : to %3A like CGI.escape
     #
-    # URI.escape is obsolete in Ruby 2.7. Ignore this error until we're able to
-    # switch to a different escape mechanism. If this is JRuby, we can't mask
-    # the error message, because this isn't thread safe. JRuby shouldn't be
-    # using Ruby 2.7 or raising the warning anyway.
-    orig_verbose = $VERBOSE
-    $VERBOSE = nil unless Puppet::Util::Platform.jruby?
-    begin
-      encoded += rfc2396_escape(parts[:path]) unless parts[:path].nil?
-    ensure
-      $VERBOSE = orig_verbose unless Puppet::Util::Platform.jruby?
-    end
+    encoded += rfc2396_escape(parts[:path]) unless parts[:path].nil?
 
     # each query parameter
     if !parts[:query].nil?
@@ -495,18 +442,18 @@ module Util
   module_function :uri_encode
 
   # From https://github.com/ruby/ruby/blob/v2_7_3/lib/uri/rfc2396_parser.rb#L24-L46
-  ALPHA = "a-zA-Z".freeze
-  ALNUM = "#{ALPHA}\\d".freeze
-  UNRESERVED = "\\-_.!~*'()#{ALNUM}".freeze
-  RESERVED = ";/?:@&=+$,\\[\\]".freeze
+  ALPHA = "a-zA-Z"
+  ALNUM = "#{ALPHA}\\d"
+  UNRESERVED = "\\-_.!~*'()#{ALNUM}"
+  RESERVED = ";/?:@&=+$,\\[\\]"
   UNSAFE = Regexp.new("[^#{UNRESERVED}#{RESERVED}]").freeze
 
-  HEX = "a-fA-F\\d".freeze
+  HEX = "a-fA-F\\d"
   ESCAPED = Regexp.new("%[#{HEX}]{2}").freeze
 
   def rfc2396_escape(str)
     str.gsub(UNSAFE) do |match|
-      tmp = ''
+      tmp = ''.dup
       match.each_byte do |uc|
         tmp << sprintf('%%%02X', uc)
       end
@@ -538,7 +485,7 @@ module Util
             IO::new(f.to_i).close rescue nil
           end
         end
-      rescue Errno::ENOENT # /proc/self/fd not found
+      rescue Errno::ENOENT, Errno::ENOTDIR # /proc/self/fd not found, /proc/self not a dir
         3.upto(256){|fd| IO::new(fd).close rescue nil}
       end
 
@@ -662,19 +609,18 @@ module Util
         tempfile = Puppet::FileSystem::Uniquefile.new(Puppet::FileSystem.basename_string(file), Puppet::FileSystem.dir_string(file))
       end
 
-
       effective_mode =
-      if !Puppet::Util::Platform.windows?
-        # Grab the current file mode, and fall back to the defaults.
+        if !Puppet::Util::Platform.windows?
+          # Grab the current file mode, and fall back to the defaults.
 
-        if Puppet::FileSystem.exist?(file)
-          stat = Puppet::FileSystem.lstat(file)
-          tempfile.chown(stat.uid, stat.gid)
-          stat.mode
-        else
-          mode
+          if Puppet::FileSystem.exist?(file)
+            stat = Puppet::FileSystem.lstat(file)
+            tempfile.chown(stat.uid, stat.gid)
+            stat.mode
+          else
+            mode
+          end
         end
-      end
 
       # OK, now allow the caller to write the content of the file.
       yield tempfile
@@ -723,6 +669,7 @@ module Util
         if Puppet::FileSystem.exist?(file) && Puppet::FileSystem.directory?(file)
           raise Errno::EISDIR, _("Is a directory: %{directory}") % { directory: file }
         end
+
         File.rename(tempfile.path, Puppet::FileSystem.path_string(file))
       end
     ensure
@@ -733,7 +680,6 @@ module Util
       end
     end
 
-
     # Ideally, we would now fsync the directory as well, but Ruby doesn't
     # have support for that, and it doesn't matter /that/ much...
 
@@ -760,8 +706,8 @@ module Util
   #  code (e.g. webrick), and we have no idea what they might throw.
   rescue Exception => err
     ## NOTE: when debugging spec failures, these two lines can be very useful
-    #puts err.inspect
-    #puts Puppet::Util.pretty_backtrace(err.backtrace)
+    # puts err.inspect
+    # puts Puppet::Util.pretty_backtrace(err.backtrace)
     Puppet.log_exception(err, "#{message}: #{err}")
     Puppet::Util::Log.force_flushqueue()
     exit(code)
@@ -794,12 +740,11 @@ module Util
 end
 end
 
-
-require 'puppet/util/errors'
-require 'puppet/util/metaid'
-require 'puppet/util/classgen'
-require 'puppet/util/docs'
-require 'puppet/util/execution'
-require 'puppet/util/logging'
-require 'puppet/util/package'
-require 'puppet/util/warnings'
+require_relative 'util/errors'
+require_relative 'util/metaid'
+require_relative 'util/classgen'
+require_relative 'util/docs'
+require_relative 'util/execution'
+require_relative 'util/logging'
+require_relative 'util/package'
+require_relative 'util/warnings'
