@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../../puppet/util/tagging'
 require_relative '../../puppet/util/classgen'
 require_relative '../../puppet/util/psych_support'
@@ -20,13 +22,12 @@ class Puppet::Util::Log
 
   # Create a new destination type.
   def self.newdesttype(name, options = {}, &block)
-
     dest = genclass(
       name,
-      :parent     => Puppet::Util::Log::Destination,
-      :prefix     => "Dest",
-      :block      => block,
-      :hash       => @desttypes,
+      :parent => Puppet::Util::Log::Destination,
+      :prefix => "Dest",
+      :block => block,
+      :hash => @desttypes,
       :attributes => options
     )
     dest.match(dest.name)
@@ -62,19 +63,19 @@ class Puppet::Util::Log
     @destinations.keys.each { |dest|
       close(dest)
     }
-    #TRANSLATORS "Log.close_all" is a method name and should not be translated
+    # TRANSLATORS "Log.close_all" is a method name and should not be translated
     raise Puppet::DevError.new(_("Log.close_all failed to close %{destinations}") % { destinations: @destinations.keys.inspect }) if !@destinations.empty?
   end
 
   # Flush any log destinations that support such operations.
   def Log.flush
-    @destinations.each { |type, dest|
+    @destinations.each { |_type, dest|
       dest.flush if dest.respond_to?(:flush)
     }
   end
 
   def Log.autoflush=(v)
-    @destinations.each do |type, dest|
+    @destinations.each do |_type, dest|
       dest.autoflush = v if dest.respond_to?(:autoflush=)
     end
   end
@@ -84,6 +85,7 @@ class Puppet::Util::Log
   def Log.create(hash)
     raise Puppet::DevError, _("Logs require a level") unless hash.include?(:level)
     raise Puppet::DevError, _("Invalid log level %{level}") % { level: hash[:level] } unless @levels.index(hash[:level])
+
     @levels.index(hash[:level]) >= @loglevel ? Puppet::Util::Log.new(hash) : nil
   end
 
@@ -125,11 +127,11 @@ class Puppet::Util::Log
   # Create a new log destination.
   def Log.newdestination(dest)
     # Each destination can only occur once.
-    if @destinations.find { |name, obj| obj.name == dest }
+    if @destinations.find { |_name, obj| obj.name == dest }
       return
     end
 
-    _, type = @desttypes.find do |name, klass|
+    _, type = @desttypes.find do |_name, klass|
       klass.match?(dest)
     end
 
@@ -196,7 +198,7 @@ class Puppet::Util::Log
 
     queuemessage(msg) if @destinations.length == 0
 
-    @destinations.each do |name, dest|
+    @destinations.each do |_name, dest|
       dest.handle(msg)
     end
   end
@@ -207,6 +209,7 @@ class Puppet::Util::Log
 
   def Log.flushqueue
     return unless @destinations.size >= 1
+
     @queued.each do |msg|
       Log.newmessage(msg)
     end
@@ -235,7 +238,7 @@ class Puppet::Util::Log
   def Log.reopen
     Puppet.notice _("Reopening log files")
     types = @destinations.keys
-    @destinations.each { |type, dest|
+    @destinations.each { |_type, dest|
       dest.close if dest.respond_to?(:close)
     }
     @destinations.clear
@@ -293,7 +296,6 @@ class Puppet::Util::Log
     nil
   end
 
-
   attr_accessor :time, :remote, :file, :line, :pos, :issue_code, :environment, :node, :backtrace
   attr_reader :level, :message, :source
 
@@ -313,6 +315,7 @@ class Puppet::Util::Log
     [:file, :line, :pos, :issue_code, :environment, :node, :backtrace].each do |attr|
       value = args[attr]
       next unless value
+
       send(attr.to_s + '=', value)
     end
 
@@ -332,6 +335,7 @@ class Puppet::Util::Log
     %w(file line pos issue_code environment node backtrace).each do |name|
       value = data[name]
       next unless value
+
       send(name + '=', value)
     end
   end
@@ -368,16 +372,18 @@ class Puppet::Util::Log
   end
 
   def message=(msg)
-    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    # TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
     raise ArgumentError, _("Puppet::Util::Log requires a message") unless msg
+
     @message = msg.to_s
   end
 
   def level=(level)
-    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    # TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
     raise ArgumentError, _("Puppet::Util::Log requires a log level") unless level
-    #TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
+    # TRANSLATORS 'Puppet::Util::Log' refers to a Puppet source code class
     raise ArgumentError, _("Puppet::Util::Log requires a symbol or string") unless level.respond_to? "to_sym"
+
     @level = level.to_sym
     raise ArgumentError, _("Invalid log level %{level}") % { level: @level } unless self.class.validlevel?(@level)
 
@@ -418,7 +424,6 @@ class Puppet::Util::Log
     end
     msg
   end
-
 end
 
 # This is for backward compatibility from when we changed the constant to
