@@ -1,17 +1,18 @@
-require 'puppet/util'
+# frozen_string_literal: true
+
+require_relative '../../puppet/util'
 module Puppet::Util::RDoc
   module_function
 
   # launch a rdoc documentation process
   # with the files/dir passed in +files+
   def rdoc(outputdir, files, charset = nil)
-
     # then rdoc
     require 'rdoc/rdoc'
     require 'rdoc/options'
 
     # load our parser
-    require 'puppet/util/rdoc/parser'
+    require_relative 'rdoc/parser'
 
     r = RDoc::RDoc.new
 
@@ -26,13 +27,6 @@ module Puppet::Util::RDoc
 
     options << "--force-update"
     options += [ "--charset", charset] if charset
-    # Rdoc root default is Dir.pwd, but the win32-dir gem monkey patches Dir.pwd
-    # replacing Ruby's normal / with \.  When RDoc generates relative paths it
-    # uses relative_path_from that will generate errors when the slashes don't
-    # properly match.  This is a workaround for that issue.
-    if Puppet::Util::Platform.windows? && RDoc::VERSION !~ /^[0-3]\./
-      options += [ "--root", Dir.pwd.tr('\\', '/')]
-    end
     options += files
 
     # launch the documentation process
