@@ -1,9 +1,10 @@
+# frozen_string_literal: true
+
 require 'rdoc/generators/html_generator'
 require_relative '../../../../puppet/util/rdoc/code_objects'
 require 'digest/md5'
 
 module Generators
-
   # This module holds all the classes needed to generate the HTML documentation
   # of a bunch of puppet manifests.
   #
@@ -51,7 +52,6 @@ module Generators
 
   # This is a specialized HTMLGenerator tailored to Puppet manifests
   class PuppetGenerator < HTMLGenerator
-
     def PuppetGenerator.for(options)
       AllReferences::reset
       HtmlMethod::reset
@@ -63,18 +63,18 @@ module Generators
       end
     end
 
-    def initialize(options) #:not-new:
-      @options    = options
+    def initialize(options) # :not-new:
+      @options = options
       load_html_template
     end
 
     # loads our own html template file
     def load_html_template
-        require_relative '../../../../puppet/util/rdoc/generators/template/puppet/puppet'
-        extend RDoc::Page
+      require_relative '../../../../puppet/util/rdoc/generators/template/puppet/puppet'
+      extend RDoc::Page
     rescue LoadError
-        $stderr.puts "Could not find Puppet template '#{template}'"
-        exit 99
+      $stderr.puts "Could not find Puppet template '#{template}'"
+      exit 99
     end
 
     def gen_method_index
@@ -115,6 +115,7 @@ module Generators
       # build the modules, classes and per modules classes and define list
       @toplevels.each do |toplevel|
         next unless toplevel.document_self
+
         file = HtmlFile.new(toplevel, @options, FILE_DIR)
         classes = []
         methods = []
@@ -143,7 +144,7 @@ module Generators
         # generate nodes and plugins found
         classes.each do |k|
           if k.context.is_module?
-            k.context.each_node do |name,node|
+            k.context.each_node do |_name,node|
               nodes << HTMLPuppetNode.new(node, toplevel, NODE_DIR, @options)
               @nodes << nodes.last
             end
@@ -195,13 +196,13 @@ module Generators
 
     # generate all the subdirectories, modules, classes and files
     def gen_sub_directories
-        super
-        File.makedirs(MODULE_DIR)
-        File.makedirs(NODE_DIR)
-        File.makedirs(PLUGIN_DIR)
+      super
+      File.makedirs(MODULE_DIR)
+      File.makedirs(NODE_DIR)
+      File.makedirs(PLUGIN_DIR)
     rescue
-        $stderr.puts $ERROR_INFO.message
-        exit 1
+      $stderr.puts $ERROR_INFO.message
+      exit 1
     end
 
     # generate the index of modules
@@ -220,11 +221,11 @@ module Generators
       end
 
       values = {
-        "entries"    => res,
+        "entries" => res,
         'list_title' => CGI.escapeHTML(title),
-        'index_url'  => main_url,
-        'charset'    => @options.charset,
-        'style_url'  => style_url('', @options.css),
+        'index_url' => main_url,
+        'charset' => @options.charset,
+        'style_url' => style_url('', @options.css),
       }
 
       Puppet::FileSystem.open(filename, nil, "w:UTF-8") do |f|
@@ -240,9 +241,8 @@ module Generators
 
           gen_composite_index(
             file,
-              RDoc::Page::COMBO_INDEX,
-
-              "#{MODULE_DIR}/fr_#{file["file"].context.module_name}.html")
+            RDoc::Page::COMBO_INDEX,
+            "#{MODULE_DIR}/fr_#{file["file"].context.module_name}.html")
         end
       end
     end
@@ -287,15 +287,15 @@ module Generators
 
       values = {
         "module" => module_name,
-        "classes"    => res1,
+        "classes" => res1,
         'classes_title' => CGI.escapeHTML("Classes"),
         'defines_title' => CGI.escapeHTML("Defines"),
         'facts_title' => CGI.escapeHTML("Custom Facts"),
         'plugins_title' => CGI.escapeHTML("Plugins"),
         'nodes_title' => CGI.escapeHTML("Nodes"),
-        'index_url'  => main_url,
-        'charset'    => @options.charset,
-        'style_url'  => style_url('', @options.css),
+        'index_url' => main_url,
+        'charset' => @options.charset,
+        'style_url' => style_url('', @options.css),
       }
 
       values["defines"] = res2 if res2.size>0
@@ -347,7 +347,6 @@ module Generators
 
       ref
     end
-
   end
 
   # This module is used to generate a referenced full name list of ContextUser
@@ -397,7 +396,7 @@ module Generators
       resources.each do |r|
         row = {}
         if r.section == section and r.document_self
-          row["name"]        = CGI.escapeHTML(r.name)
+          row["name"] = CGI.escapeHTML(r.name)
           desc = r.description.strip
           row["m_desc"]      = desc unless desc.empty?
           row["aref"]        = r.aref
@@ -498,11 +497,10 @@ module Generators
     def write_on(f)
       value_hash
 
-        template = TemplatePage.new(
-          RDoc::Page::BODYINC,
-            RDoc::Page::NODE_PAGE,
-
-            RDoc::Page::METHOD_LIST)
+      template = TemplatePage.new(
+        RDoc::Page::BODYINC,
+        RDoc::Page::NODE_PAGE,
+        RDoc::Page::METHOD_LIST)
       template.write_html_on(f, @values)
     end
 
@@ -535,7 +533,6 @@ module Generators
       @values["childs"] = cl unless cl.empty?
 
       @values["sections"] = @context.sections.map do |section|
-
         secdata = {
           "sectitle" => section.title,
           "secsequence" => section.sequence,
@@ -571,10 +568,11 @@ module Generators
       res = []
       atts.each do |att|
         next unless att.section == section
+
         if att.visibility == :public || att.visibility == :protected || @options.show_all
           entry = {
-            "name"   => CGI.escapeHTML(att.name),
-            "rw"     => att.rw,
+            "name" => CGI.escapeHTML(att.name),
+            "rw" => att.rw,
             "a_desc" => markup(att.comment, true)
           }
           unless att.visibility == :public || att.visibility == :protected
@@ -648,11 +646,6 @@ module Generators
   end
 
   class HTMLPuppetModule < HtmlClass
-
-    def initialize(context, html_file, prefix, options)
-      super(context, html_file, prefix, options)
-    end
-
     def value_hash
       @values = super
 
@@ -699,7 +692,6 @@ module Generators
     def plugins
       @context.plugins
     end
-
   end
 
   class HTMLPuppetPlugin < ContextUser
@@ -746,11 +738,10 @@ module Generators
     def write_on(f)
       value_hash
 
-        template = TemplatePage.new(
-          RDoc::Page::BODYINC,
-            RDoc::Page::PLUGIN_PAGE,
-
-            RDoc::Page::PLUGIN_LIST)
+      template = TemplatePage.new(
+        RDoc::Page::BODYINC,
+        RDoc::Page::PLUGIN_PAGE,
+        RDoc::Page::PLUGIN_LIST)
       template.write_html_on(f, @values)
     end
 
@@ -818,7 +809,6 @@ module Generators
     def <=>(other)
       self.name <=> other.name
     end
-
   end
 
   class HTMLPuppetResource
@@ -900,7 +890,6 @@ module Generators
       res = @context.parent.find_symbol(symbol, method)
       res && res.viewer
     end
-
   end
 
   class PuppetGeneratorInOne < HTMLGeneratorInOne
@@ -908,5 +897,4 @@ module Generators
       gen_an_index(HtmlMethod.all_methods, 'Defines')
     end
   end
-
 end
