@@ -12,7 +12,6 @@ describe Puppet::HTTP::Service::Compiler do
   let(:node) { Puppet::Node.new(certname) }
   let(:facts) { Puppet::Node::Facts.new(certname) }
   let(:catalog) { Puppet::Resource::Catalog.new(certname) }
-  let(:status) { Puppet::Status.new }
   let(:formatter) { Puppet::Network::FormatHandler.format(:json) }
 
   before :each do
@@ -69,7 +68,7 @@ describe Puppet::HTTP::Service::Compiler do
       subject.post_catalog(certname, environment: environment, facts: facts)
     end
 
-    it 'submits facts as pson if set as the preferred format' do
+    it 'submits facts as pson if set as the preferred format', if: Puppet.features.pson? do
       Puppet[:preferred_serialization_format] = "pson"
 
       stub_request(:post, uri)
@@ -142,20 +141,22 @@ describe Puppet::HTTP::Service::Compiler do
 
     it 'does not accept msgpack by default' do
       stub_request(:post, uri)
-        .with(headers: {'Accept' => 'application/vnd.puppet.rich+json, application/json, text/pson'})
+        .with(headers: {'Accept' => 'application/vnd.puppet.rich+json, application/json'})
         .to_return(**catalog_response)
 
       allow(Puppet.features).to receive(:msgpack?).and_return(false)
+      allow(Puppet.features).to receive(:pson?).and_return(false)
 
       subject.post_catalog(certname, environment: environment, facts: facts)
     end
 
     it 'accepts msgpack & rich_json_msgpack if the gem is present' do
       stub_request(:post, uri)
-        .with(headers: {'Accept' => 'application/vnd.puppet.rich+json, application/json, application/vnd.puppet.rich+msgpack, application/x-msgpack, text/pson'})
+        .with(headers: {'Accept' => 'application/vnd.puppet.rich+json, application/json, application/vnd.puppet.rich+msgpack, application/x-msgpack'})
         .to_return(**catalog_response)
 
       allow(Puppet.features).to receive(:msgpack?).and_return(true)
+      allow(Puppet.features).to receive(:pson?).and_return(false)
 
       subject.post_catalog(certname, environment: environment, facts: facts)
     end
@@ -593,68 +594,7 @@ describe Puppet::HTTP::Service::Compiler do
       invalid_facts = Puppet::Node::Facts.new(certname, {'invalid_utf8_sequence' => "\xE2\x82".force_encoding('binary')})
       expect {
         subject.put_facts(certname, environment: 'production', facts: invalid_facts)
-      }.to raise_error(Puppet::HTTP::SerializationError, /Failed to serialize Puppet::Node::Facts to json: "\\xE2" from ASCII-8BIT to UTF-8/)
-    end
-  end
-
-  context 'when getting status' do
-    let(:uri) { %r{/puppet/v3/status/ziggy} }
-    let(:status_response) { { body: formatter.render(status), headers: {'Content-Type' => formatter.mime } } }
-
-    it 'always sends production' do
-      stub_request(:get, uri)
-          .with(query: hash_including("environment" => "production"))
-          .to_return(**status_response)
-
-      subject.get_status(certname)
-    end
-
-    it 'returns a deserialized status' do
-      stub_request(:get, uri)
-        .to_return(**status_response)
-
-      _, s = subject.get_status(certname)
-      expect(s).to be_a(Puppet::Status)
-      expect(s.status).to eq("is_alive" => true)
-    end
-
-    it 'returns the request response' do
-      stub_request(:get, uri)
-        .to_return(**status_response)
-
-      resp, _ = subject.get_status(certname)
-      expect(resp).to be_a(Puppet::HTTP::Response)
-    end
-
-    it 'raises a response error if unsuccessful' do
-      stub_request(:get, uri)
-        .to_return(status: [500, "Server Error"])
-
-      expect {
-        subject.get_status(certname)
-      }.to raise_error do |err|
-        expect(err).to be_an_instance_of(Puppet::HTTP::ResponseError)
-        expect(err.message).to eq('Server Error')
-        expect(err.response.code).to eq(500)
-      end
-    end
-
-    it 'raises a protocol error if the content-type header is missing' do
-      stub_request(:get, uri)
-        .to_return(body: "content-type is missing")
-
-      expect {
-        subject.get_status(certname)
-      }.to raise_error(Puppet::HTTP::ProtocolError, /No content type in http response; cannot parse/)
-    end
-
-    it 'raises a serialization error if the content is invalid' do
-      stub_request(:get, uri)
-        .to_return(body: "this isn't valid JSON", headers: {'Content-Type' => 'application/json'})
-
-      expect {
-        subject.get_status(certname)
-      }.to raise_error(Puppet::HTTP::SerializationError, /Failed to deserialize Puppet::Status from json/)
+      }.to raise_error(Puppet::HTTP::SerializationError, /Failed to serialize Puppet::Node::Facts to json: ("\\xE2" from ASCII-8BIT to UTF-8|partial character in source, but hit end)/)
     end
   end
 
