@@ -65,6 +65,7 @@ describe Puppet::Util::SELinux do
         '/'        => 'ext3',
         '/sys'     => 'sysfs',
         '/mnt/nfs' => 'nfs',
+        '/mnt/zfs' => 'zfs',
         '/proc'    => 'proc',
         '/dev'     => 'tmpfs' })
     end
@@ -85,6 +86,10 @@ describe Puppet::Util::SELinux do
       expect(selinux_label_support?('/dev/shm/testfile')).to be_truthy
     end
 
+    it "should return true if zfs" do
+      expect(selinux_label_support?('/mnt/zfs/testfile')).to be_truthy
+    end
+
     it "should return false for a noncapable filesystem" do
       expect(selinux_label_support?('/mnt/nfs/testfile')).to be_falsey
     end
